<?php


namespace Drupal\helpdesk_zendesk;


use Drupal\helpdesk_integration\Service as BaseService;
use Drupal\helpdesk_zendesk\Plugin\HelpdeskIntegration\Zendesk;

class Service {

  /**
   * The helpdesk integration services.
   *
   * @var \Drupal\helpdesk_integration\Service
   */
  protected $service;

  /**
   * Service constructor.
   *
   * @param \Drupal\helpdesk_integration\Service $service
   *   The helpdesk integration services.
   */
  public function __construct(BaseService $service) {
    $this->service = $service;
  }

  /**
   * Get a list of active Zendesk instances.
   *
   * @return \Drupal\helpdesk_integration\HelpdeskInterface[]
   *   A list of active Zendesk instances.
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function getZendeskInstances(): array {
    $instances = [];
    foreach ($this->service->getHelpdeskInstances() as $helpdeskInstance) {
      $plugin = $helpdeskInstance->getPlugin();
      if ($plugin instanceof Zendesk) {
        $instances[] = $helpdeskInstance;
      }
    }
    return $instances;
  }
}
